@@ -19,19 +19,16 @@ local system, and will be found at B</etc/blogspam/stoplist>.
 
 =cut
 
-=head1 LICENSE
-
-This code is licensed under the terms of the GNU General Public
-License, version 2.  See included file GPL-2 for details.
-
-=cut
-
 =head1 AUTHOR
 
-Steve
---
+=over 4
+
+=item Steve Kemp
+
 http://www.steve.org.uk/
 
+=back
+
 =cut
 
 =head1 LICENSE
